@@ -4,6 +4,7 @@ Multiplestatmenu<-function()
 cat("\n")
   file.menu <- c("NCA --> Statistical analysis for 2x2x2 crossover study",
                  "NCA --> Statistical analysis for replicate study",
+                 "NCA --> Statistical analysis for parallel study",
                  "Back to the previous step",
                  "Quit")
  cat("\n")
@@ -20,13 +21,19 @@ cat("\n")
     else {
     if (pick == 3){
         cat("\n")
-       go()
+        ParaNCA.MIXmenu()
        }
     else {
     if (pick == 4){
         cat("\n")
+       go()
+       }   
+    else {
+    if (pick == 5){
+        cat("\n")
       cat("\nThank you for using bear!  Bye now. \n")}
        }
       }
     }
- }
\ No newline at end of file
+ }
+} 
\ No newline at end of file
