@@ -6,10 +6,9 @@ cat(" This method selects data points to estimate lambda(z) based on the  maximu
 cat(" adjustedR squred values.  It starts with the last three data points from the  \n")
 cat(" concentration-time course, performing log-linear regression to calculate      \n")
 cat(" the slope of that tail portion of the concentration-time curve.  And then     \n")
-cat(" the last 4data points, the last 5 data points, on and on until it includes    \n")
-cat(" the data points of Cmax. Thus, this method may include the data point of      \n")
-cat(" (Tmax, Cmax). WNL v5.x.x has the similar algoirthms like this.  WNL v6. has   \n")
-cat(" similar algorithms except that it will rule out the data point of (Tmax, Cmax).\n")
+cat(" the last 4 data points, the last 5 data points, on and on until it excludes   \n")
+cat(" the data points of Cmax. Thus, this method may exclude the data point of      \n")
+cat(" (Tmax, Cmax). WNL v6. has the similar algoirthms like this.                   \n")
 cat("*******************************************************************************\n")
 cat("\n")
 }
\ No newline at end of file
