@@ -1,9 +1,9 @@
 description_version<-function(){
-cat("~~~  This report is generated using bear v2.2.0 for R. ~~~\n")
+cat("~~~  This report is generated using bear v2.3.0 for R. ~~~\n")
 cat("Authors: Hsin-ya Lee, Yung-jin Lee\n")
 cat("College of Pharmacy, Kaohsiung Medical University\n")
 cat("Kaohsiung, Taiwan 80708\n")
-cat("E-mail: hsinyalee@gmail.com,pkpd.taiwan@gmail.com\n")
+cat("E-mail: hsinyalee@gmail.com,mobilePK@gmail.com\n")
 cat("bear's website: http://pkpd.kmu.edu.tw/bear\n")
 cat("R website: http://www.r-project.org\n")
 cat("---------------------------------------------------\n")
