@@ -4,6 +4,7 @@ statmenu<-function()
 cat("\n")
   file.menu <- c("Statistical analysis for 2x2x2 crossover study",
                  "Statistical analysis for replicate study",
+                 "Statistical analysis for parallel study",
                  "Back to the previous step",
                  "Quit")
  cat("\n")
@@ -20,12 +21,18 @@ cat("\n")
     else {
     if (pick == 3){
         cat("\n")
-       go()
+        ParaMIXmenu()
        }
     else {
     if (pick == 4){
         cat("\n")
+       go()
+       }
+    else {
+    if (pick == 5){
+        cat("\n")
       cat("\nThank you for using bear!  Bye now. \n")}
+         } 
        }
       }
     }
